(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    135770,       4264]
NotebookOptionsPosition[    130429,       4108]
NotebookOutlinePosition[    130832,       4126]
CellTagsIndexPosition[    130789,       4123]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox["Knight\[CloseCurlyQuote]s Tour Code",
 FontSize->36,
 FontWeight->"Bold"]], "Subtitle",
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {0, 0}},
 TextAlignment->Center,
 FontColor->GrayLevel[1],
 Background->RGBColor[1, 0.603647, 0.180026]],

Cell[TextData[{
 StyleBox["Author:",
  FontWeight->"Bold"],
 StyleBox["\tDr Colin Rose, ",
  FontColor->GrayLevel[0]],
 ButtonBox["colin@tri.org.au",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["mailto:colin@tri.org.au"], None},
  ButtonNote->"Fee Fi Fo Fum"],
 StyleBox["\nDesigned:",
  FontWeight->"Bold"],
 "\tTheoretical Research Institute, Sydney\n",
 StyleBox["Versions:",
  FontWeight->"Bold"],
 " \t1998, 2002, 2006, 2010"
}], "Text",
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {0, 0}},
 Background->RGBColor[1, 0.972488, 0.850004]],

Cell[CellGroupData[{

Cell["\<\
Knight\[CloseCurlyQuote]s Tour Functions \[LongDash] Load me up!\
\>", "Section"],

Cell[TextData[{
 StyleBox["KnightTour[",
  FontWeight->"Bold",
  FontColor->RGBColor[0.556863, 0.137255, 0.137255]],
 StyleBox["rows, columns, startingpoint(s)",
  FontColor->RGBColor[0.521569, 0.388235, 0.388235]],
 StyleBox["]",
  FontWeight->"Bold",
  FontColor->RGBColor[0.556863, 0.137255, 0.137255]],
 " finds ALL solutions to the knight's tour problem. For instance, ",
 StyleBox["KnightTour[",
  FontWeight->"Bold",
  FontColor->RGBColor[0.556863, 0.137255, 0.137255]],
 StyleBox["4, 5, {2,3}",
  FontColor->RGBColor[0.521569, 0.388235, 0.388235]],
 StyleBox["]",
  FontWeight->"Bold",
  FontColor->RGBColor[0.556863, 0.137255, 0.137255]],
 " finds all solutions for a chess board that is 4 rows high, 5 columns wide, \
with the knight starting out at the intersection of row 2 and column 3. Note \
that ",
 StyleBox["{1,1}",
  FontColor->RGBColor[0.521569, 0.388235, 0.388235]],
 " denotes the bottom left corner of the board. Similarly, ",
 StyleBox["KnightTour[",
  FontWeight->"Bold",
  FontColor->RGBColor[0.556863, 0.137255, 0.137255]],
 StyleBox["4, 5, { {1,2}, {3,1}, {4,3} }",
  FontColor->RGBColor[0.521569, 0.388235, 0.388235]],
 StyleBox["]",
  FontWeight->"Bold",
  FontColor->RGBColor[0.556863, 0.137255, 0.137255]],
 " finds all solutions for a chess board that is 4 rows high, 5 columns wide, \
when the knight's first 3 moves are ",
 StyleBox["{1, 2}",
  FontColor->RGBColor[0.521569, 0.388235, 0.388235]],
 ", then ",
 StyleBox["{3,1}",
  FontColor->RGBColor[0.521569, 0.388235, 0.388235]],
 " and then ",
 StyleBox["{4,3}",
  FontColor->RGBColor[0.521569, 0.388235, 0.388235]],
 ". \nTo suppress the printing/plotting of each path, use:  ",
 StyleBox["KnightTour[",
  FontWeight->"Bold",
  FontColor->RGBColor[0.556863, 0.137255, 0.137255]],
 StyleBox["rows, columns, startingpoint(s), 1",
  FontColor->RGBColor[0.521569, 0.388235, 0.388235]],
 StyleBox["] ",
  FontWeight->"Bold",
  FontColor->RGBColor[0.556863, 0.137255, 0.137255]],
 "\[NonBreakingSpace]\[Rule] this is useful to simply check the number of \
solutions from any starting point (without cluttering up the screen),"
}], "Text",
 Hyphenation->False],

Cell[TextData[{
 StyleBox["KnightTour[",
  FontWeight->"Bold",
  FontColor->RGBColor[0.556863, 0.137255, 0.137255]],
 " ",
 StyleBox["rows, columns, startingpoint(s), ",
  FontColor->RGBColor[0.521569, 0.388235, 0.388235]],
 StyleBox["endingpoint(s)",
  FontColor->RGBColor[1, 0, 0]],
 StyleBox["]",
  FontWeight->"Bold",
  FontColor->RGBColor[0.556863, 0.137255, 0.137255]],
 " supports an optional 4th argument \[OpenCurlyQuote]",
 StyleBox["endingpoint(s)",
  FontColor->RGBColor[1, 0, 0]],
 "\[CloseCurlyQuote] which allows one to specify the ending position or the \
ending path, and so find ALL the solutions that satisfy both the given \
starting path and ending path. Indeed, ",
 StyleBox["if the ending path is known, it should always be specified",
  FontColor->RGBColor[0, 0, 1]],
 " as this makes finding the solution set far more efficient. The more given \
points specified, the faster the solutions! [ Dan Thomasson suggested the ",
 StyleBox["endingpoint",
  FontColor->RGBColor[1, 0, 0]],
 " feature.]"
}], "Text"],

Cell["\<\
KnightTour[rows_Integer, columns_Integer, start_List, end_List:{}, \
HidePaths_Integer:0] := 
   Module[{sR = rows+1, sC = columns+1, i = 0, j = 0, path, endMoves, tree = \
{0}, SNew, KnightMoves, FeasibleMoves, area},
           
         path = If[IntegerQ[start[[1]]], {start}, start];
\t
\tendMoves  = If[end != {}, If[IntegerQ[end[[1]]],{end},end], {}];
\t
   \t     area = (rows*columns) - Length[endMoves];
\t  
    KnightMoves[lis_List] := KnightMoves[lis] = Complement[
        Cases[ Map[ lis +#&, \
{{1,2},{1,-2},{-1,2},{-1,-2},{2,1},{2,-1},{-2,1},{-2,-1}}], {x_/;0<x<sR, \
y_/;0<y<sC}], endMoves];
                    
    While[First[tree]==0,
\t 
\t   SNew = Complement[KnightMoves[Last[path]], path];
\t               
      
       Which[ SNew == {},         (* Back  *) 
                                  j++;  path = tree[[-1]];  tree = Drop[tree, \
-1],
\t                                         
              Length[SNew] == 1,  (* Advance -> single branch *)
                                  AppendTo[path, First[SNew]]; 
                                  If[ Length[path] == area,
                                       Which[ endMoves == {},  
                                                 i++; If[HidePaths === 0, \
Print[\"Solution \",i,\": \", Flatten[{path, endMoves},1]]; \
PlotTour[Evaluate[Flatten[{path, endMoves}, 1]]] ],
                                              Intersection[KnightMoves[First[\
endMoves]],{Last[path]}] == {Last[path]},
                                                 i++; If[HidePaths === 0, \
Print[\"Solution \",i,\": \", Flatten[{path, endMoves},1]]; \
PlotTour[Evaluate[Flatten[{path, endMoves}, 1]]] ] ]
                                    ],
\t                              \t                           
\t          True,               (* Advance -> multiple branches *)
\t                              tree = Join[tree, Map[Append[path, #]&, \
Rest[SNew]]] ;
                                  AppendTo[path, First[SNew]]  
           ]
\t   ]//Quiet;
\t    
\t    Print[\"All Done. I traversed \", j, \" paths. Solutions: \", i]  ] \t\
\>", "Input",
 PageWidth->Infinity,
 FontSize->10],

Cell[TextData[{
 StyleBox["PlotTour[",
  FontWeight->"Bold",
  FontColor->RGBColor[0.556863, 0.137255, 0.137255]],
 StyleBox["path",
  FontColor->RGBColor[0.521569, 0.388235, 0.388235]],
 StyleBox["]",
  FontWeight->"Bold",
  FontColor->RGBColor[0.556863, 0.137255, 0.137255]],
 " plots out a particular path, marking the starting point ",
 StyleBox["GREEN",
  FontWeight->"Bold",
  FontColor->RGBColor[0.192721, 0.629999, 0.0945144]],
 " and the ending point ",
 StyleBox["RED",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 ". The ",
 StyleBox["PlotTour",
  FontWeight->"Bold",
  FontColor->RGBColor[0.556863, 0.137255, 0.137255]],
 " function automatically checks if the tour is ",
 StyleBox["closed",
  FontWeight->"Bold"],
 " (re-entrant). If the tour is closed, the notion of a starting/ending point \
is not meaningful and therefore the red/green markers are not plotted, and \
the end point is joined to the start point. The second argument, dotsize, is \
optional and allows one to vary the pointsize of the black dots at the centre \
of each square. The default size is 7."
}], "Text"],

Cell["\<\
PlotTour[path_, dotsize_:7] := Module[{moves, sol, closedpath, rows, columns, \
A, B},
    
         moves = {{1,2},{1,-2},{-1,2},{-1,-2},{2,1},{2,-1},{-2,1},{-2,-1}};
    
           sol = Map[Reverse, path];
    
    closedpath = If[ \
Intersection[Map[#+First[path]&,moves],{Last[path]}]=={}, False, True];
    
    If[closedpath === True, AppendTo[sol, First[sol]]];
    
    {rows, columns} = Map[Max, Transpose[path]];
    
    A = ListPlot[sol, Joined -> False, PlotStyle -> \
{AbsolutePointSize[dotsize], Black}, 
                 Frame -> False, PlotRange -> {{0.5, columns+.5}, {0.5, \
rows+.5}}, 
                 AspectRatio -> rows/columns, Axes -> False, Ticks -> False, 
                 GridLines -> {Table[i - 1/2, {i, columns+1}], Table[i - 1/2, \
{i, rows+1}]},
                 GridLinesStyle \[Rule] Directive[RGBColor[0.67, 0.68, 0.86]], 
                 Prolog -> If[closedpath===True, {},
                              {{Hue[0.35,1,1], Rectangle[First[sol]-0.2, \
First[sol]+0.2]}, 
                               {Hue[1],        Rectangle[Last[sol] -0.2, \
Last[sol] +0.2]}}] ];
    B = ListPlot[sol, Joined -> True, PlotStyle -> Red];
    Show[A, B, DisplayFunction -> (Print[#]; &)]   ]\
\>", "Input",
 PageWidth->Infinity,
 FontSize->10],

Cell[BoxData[""], "Input"],

Cell[TextData[{
 StyleBox["[",
  FontSize->10,
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[" Revision:",
  FontSize->10,
  FontSlant->"Italic",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[" May 2006:\n* Removed FeasibleMoves (the compiled version of \
Complement) because, under ",
  FontSize->10,
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["Mathematica",
  FontSize->10,
  FontSlant->"Italic",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[" 5, the inbuilt Complement does the 'trick'. \n* Timings are about \
8 times faster than in 2002 (part hardware, part software), and about 80 \
times faster than in 1998. \n* Added option to suppress printing/plotting of \
paths \[Dash] useful for just checking the number of solutions ]",
  FontSize->10,
  FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
 StyleBox["[",
  FontSize->10,
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[" Revision:",
  FontSize->10,
  FontSlant->"Italic",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[" May 2010:\n* Updated for ",
  FontSize->10,
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["Mathematica",
  FontSize->10,
  FontSlant->"Italic",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[" 7 ]",
  FontSize->10,
  FontColor->RGBColor[0, 0, 1]]
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Section"],

Cell[TextData[{
 "Consider a chess board that is 4 x 5: ",
 StyleBox["i.e.",
  FontSlant->"Italic"],
 " 4 rows high and 5 columns wide. We start off with the knight sitting on \
the square {1, 3}. This notation denotes the square at the intersection of \
the 1st row from the bottom and the 3rd column from the left."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"KnightTour", "[", 
   RowBox[{"4", ",", " ", "5", ",", " ", 
    RowBox[{"{", 
     RowBox[{"1", ",", " ", "3"}], "}"}]}], "]"}], " "}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Solution \"\>", "\[InvisibleSpace]", "1", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "1"}], "}"}]}], "}"}]}],
  SequenceForm[
  "Solution ", 1, ": ", {{1, 3}, {2, 1}, {4, 2}, {3, 4}, {1, 5}, {2, 3}, {1, 
   1}, {3, 2}, {4, 4}, {2, 5}, {3, 3}, {4, 5}, {2, 4}, {1, 2}, {3, 1}, {4, 
   3}, {3, 5}, {1, 4}, {2, 2}, {4, 1}}],
  Editable->False]], "Print"],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0], AbsolutePointSize[7], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQDQEcDhD6gz0qzeCASgug0TB9Imj6YeIMaOLo5sLU
oZsLMw9dHbp96PrQ3YtuL7o56Pahi+MKB5i4gAMAmukVUQ==
     "]]}, 
   {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQDQEcDhD6gz0qzeCASgug0TB9Imj6YeIMaOLo5sLU
oZsLMw9dHbp96PrQ3YtuL7o56Pahi+MKB5i4gAMAmukVUQ==
     "]]}},
  AspectRatio->NCache[
    Rational[4, 5], 0.8],
  DisplayFunction->((Print[#]; Null)& ),
  GridLines->NCache[{{
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2], 
      Rational[9, 2], 
      Rational[11, 2]}, {
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2], 
      Rational[9, 2]}}, {{0.5, 1.5, 2.5, 3.5, 4.5, 5.5}, {0.5, 1.5, 2.5, 3.5, 
     4.5}}],
  GridLinesStyle->Directive[
    RGBColor[0.67, 0.68, 0.86]],
  PlotRange->{{0.5, 5.5}, {0.5, 4.5}},
  PlotRangeClipping->True,
  Prolog->{{
     Hue[0.35, 1, 1], 
     RectangleBox[{2.8, 0.8}, {3.2, 1.2}]}, {
     Hue[1], 
     RectangleBox[{0.8, 3.8}, {1.2, 4.2}]}},
  Ticks->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Solution \"\>", "\[InvisibleSpace]", "2", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "5"}], "}"}]}], "}"}]}],
  SequenceForm[
  "Solution ", 2, ": ", {{1, 3}, {2, 1}, {4, 2}, {3, 4}, {1, 5}, {2, 3}, {1, 
   1}, {3, 2}, {4, 4}, {2, 5}, {3, 3}, {4, 1}, {2, 2}, {1, 4}, {3, 5}, {4, 
   3}, {3, 1}, {1, 2}, {2, 4}, {4, 5}}],
  Editable->False]], "Print"],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0], AbsolutePointSize[7], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQDQEcDhD6gz0qzeCASgug0TB9Imj6YeIMaOLo5sLU
oZsLMw9dHbo7BdDUobsTpg5mHro56OpwuRvdHph5Ag4A6wkVUQ==
     "]]}, 
   {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQDQEcDhD6gz0qzeCASgug0TB9Imj6YeIMaOLo5sLU
oZsLMw9dHbo7BdDUobsTpg5mHro56OpwuRvdHph5Ag4A6wkVUQ==
     "]]}},
  AspectRatio->NCache[
    Rational[4, 5], 0.8],
  DisplayFunction->((Print[#]; Null)& ),
  GridLines->NCache[{{
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2], 
      Rational[9, 2], 
      Rational[11, 2]}, {
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2], 
      Rational[9, 2]}}, {{0.5, 1.5, 2.5, 3.5, 4.5, 5.5}, {0.5, 1.5, 2.5, 3.5, 
     4.5}}],
  GridLinesStyle->Directive[
    RGBColor[0.67, 0.68, 0.86]],
  PlotRange->{{0.5, 5.5}, {0.5, 4.5}},
  PlotRangeClipping->True,
  Prolog->{{
     Hue[0.35, 1, 1], 
     RectangleBox[{2.8, 0.8}, {3.2, 1.2}]}, {
     Hue[1], 
     RectangleBox[{4.8, 3.8}, {5.2, 4.2}]}},
  Ticks->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Solution \"\>", "\[InvisibleSpace]", "3", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "1"}], "}"}]}], "}"}]}],
  SequenceForm[
  "Solution ", 3, ": ", {{1, 3}, {2, 5}, {4, 4}, {3, 2}, {1, 1}, {2, 3}, {1, 
   5}, {3, 4}, {4, 2}, {2, 1}, {3, 3}, {4, 5}, {2, 4}, {1, 2}, {3, 1}, {4, 
   3}, {3, 5}, {1, 4}, {2, 2}, {4, 1}}],
  Editable->False]], "Print"],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0], AbsolutePointSize[7], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQDQEcDhD6gz2EFoHyGaC0ABoNE0fXB6M50NSJoKmD
mYOuTgBNHbo9MFoETT26u2A0LnfBaJg+ERzi6O5AN1fAAQBKyRVR
     "]]}, 
   {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQDQEcDhD6gz2EFoHyGaC0ABoNE0fXB6M50NSJoKmD
mYOuTgBNHbo9MFoETT26u2A0LnfBaJg+ERzi6O5AN1fAAQBKyRVR
     "]]}},
  AspectRatio->NCache[
    Rational[4, 5], 0.8],
  DisplayFunction->((Print[#]; Null)& ),
  GridLines->NCache[{{
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2], 
      Rational[9, 2], 
      Rational[11, 2]}, {
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2], 
      Rational[9, 2]}}, {{0.5, 1.5, 2.5, 3.5, 4.5, 5.5}, {0.5, 1.5, 2.5, 3.5, 
     4.5}}],
  GridLinesStyle->Directive[
    RGBColor[0.67, 0.68, 0.86]],
  PlotRange->{{0.5, 5.5}, {0.5, 4.5}},
  PlotRangeClipping->True,
  Prolog->{{
     Hue[0.35, 1, 1], 
     RectangleBox[{2.8, 0.8}, {3.2, 1.2}]}, {
     Hue[1], 
     RectangleBox[{0.8, 3.8}, {1.2, 4.2}]}},
  Ticks->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Solution \"\>", "\[InvisibleSpace]", "4", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "5"}], "}"}]}], "}"}]}],
  SequenceForm[
  "Solution ", 4, ": ", {{1, 3}, {2, 5}, {4, 4}, {3, 2}, {1, 1}, {2, 3}, {1, 
   5}, {3, 4}, {4, 2}, {2, 1}, {3, 3}, {4, 1}, {2, 2}, {1, 4}, {3, 5}, {4, 
   3}, {3, 1}, {1, 2}, {2, 4}, {4, 5}}],
  Editable->False]], "Print"],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0], AbsolutePointSize[7], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQDQEcDhD6gz2EFoHyGaC0ABoNE0fXB6M50NSJoKmD
mYOuTgBNHbo96PahuweXOTD70c1BV4fuHlz2wMwTcAAAmukVUQ==
     "]]}, 
   {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQDQEcDhD6gz2EFoHyGaC0ABoNE0fXB6M50NSJoKmD
mYOuTgBNHbo96PahuweXOTD70c1BV4fuHlz2wMwTcAAAmukVUQ==
     "]]}},
  AspectRatio->NCache[
    Rational[4, 5], 0.8],
  DisplayFunction->((Print[#]; Null)& ),
  GridLines->NCache[{{
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2], 
      Rational[9, 2], 
      Rational[11, 2]}, {
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2], 
      Rational[9, 2]}}, {{0.5, 1.5, 2.5, 3.5, 4.5, 5.5}, {0.5, 1.5, 2.5, 3.5, 
     4.5}}],
  GridLinesStyle->Directive[
    RGBColor[0.67, 0.68, 0.86]],
  PlotRange->{{0.5, 5.5}, {0.5, 4.5}},
  PlotRangeClipping->True,
  Prolog->{{
     Hue[0.35, 1, 1], 
     RectangleBox[{2.8, 0.8}, {3.2, 1.2}]}, {
     Hue[1], 
     RectangleBox[{4.8, 3.8}, {5.2, 4.2}]}},
  Ticks->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"All Done. I traversed \"\>", "\[InvisibleSpace]", "10112", 
   "\[InvisibleSpace]", "\<\" paths. Solutions: \"\>", "\[InvisibleSpace]", 
   "4"}],
  SequenceForm["All Done. I traversed ", 10112, " paths. Solutions: ", 4],
  Editable->False]], "Print"]
}, Open  ]],

Cell["\<\
To suppress the printing of the tours / plots:   (useful if there are many \
solutions and you simply want to check the number of paths)\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"KnightTour", "[", 
   RowBox[{"4", ",", " ", "5", ",", " ", 
    RowBox[{"{", 
     RowBox[{"1", ",", " ", "3"}], "}"}], ",", "1"}], "]"}], " ", "//", " ", 
  "Timing"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"All Done. I traversed \"\>", "\[InvisibleSpace]", "10112", 
   "\[InvisibleSpace]", "\<\" paths. Solutions: \"\>", "\[InvisibleSpace]", 
   "4"}],
  SequenceForm["All Done. I traversed ", 10112, " paths. Solutions: ", 4],
  Editable->False]], "Print"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.3596339999999998`", ",", "Null"}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
Here is a sample tour generated on a 4x5 board, starting at {1,3}:\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"path", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "1"}], "}"}]}], "}"}]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlotTour", "[", "path", "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0], AbsolutePointSize[7], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQDQEcDhD6gz0qzeCASgug0TB9Imj6YeIMaOLo5sLU
oZsLMw9dHbp96PrQ3YtuL7o56Pahi+MKB5i4gAMAmukVUQ==
     "]]}, 
   {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQDQEcDhD6gz0qzeCASgug0TB9Imj6YeIMaOLo5sLU
oZsLMw9dHbp96PrQ3YtuL7o56Pahi+MKB5i4gAMAmukVUQ==
     "]]}},
  AspectRatio->NCache[
    Rational[4, 5], 0.8],
  DisplayFunction->((Print[#]; Null)& ),
  GridLines->NCache[{{
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2], 
      Rational[9, 2], 
      Rational[11, 2]}, {
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2], 
      Rational[9, 2]}}, {{0.5, 1.5, 2.5, 3.5, 4.5, 5.5}, {0.5, 1.5, 2.5, 3.5, 
     4.5}}],
  GridLinesStyle->Directive[
    RGBColor[0.67, 0.68, 0.86]],
  PlotRange->{{0.5, 5.5}, {0.5, 4.5}},
  PlotRangeClipping->True,
  Prolog->{{
     Hue[0.35, 1, 1], 
     RectangleBox[{2.8, 0.8}, {3.2, 1.2}]}, {
     Hue[1], 
     RectangleBox[{0.8, 3.8}, {1.2, 4.2}]}},
  Ticks->False]], "Print"]
}, Open  ]],

Cell["A 5x5:", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"path", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "5"}], "}"}]}], "}"}]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlotTour", "[", "path", "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0], AbsolutePointSize[7], PointBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7FFpDgeoBJQWcUAVF0ATZ0ATh5kDE+dAE8el
TwBNHKYOl7vQxdHdh+4OdH0wdTB9Img0LncR8heucEI3F93eD/YA1XEZVQ==

     "]]}, 
   {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7FFpDgeoBJQWcUAVF0ATZ0ATh5kDE+dAE8el
TwBNHKYOl7vQxdHdh+4OdH0wdTB9Img0LncR8heucEI3F93eD/YA1XEZVQ==

     "]]}},
  AspectRatio->1,
  DisplayFunction->((Print[#]; Null)& ),
  GridLines->NCache[{{
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2], 
      Rational[9, 2], 
      Rational[11, 2]}, {
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2], 
      Rational[9, 2], 
      Rational[11, 2]}}, {{0.5, 1.5, 2.5, 3.5, 4.5, 5.5}, {0.5, 1.5, 2.5, 3.5,
     4.5, 5.5}}],
  GridLinesStyle->Directive[
    RGBColor[0.67, 0.68, 0.86]],
  PlotRange->{{0.5, 5.5}, {0.5, 5.5}},
  PlotRangeClipping->True,
  Prolog->{{
     Hue[0.35, 1, 1], 
     RectangleBox[{0.8, 0.8}, {1.2, 1.2}]}, {
     Hue[1], 
     RectangleBox[{4.8, 0.8}, {5.2, 1.2}]}},
  Ticks->False]], "Print"]
}, Open  ]],

Cell["A 3 x 10:", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"path", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "10"}], "}"}]}], "}"}]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlotTour", "[", "path", "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0], AbsolutePointSize[7], PointBox[CompressedData["
1:eJx1kDEKgDAMRYNTR4cMGYpU8R7tGTyC4OzVewSVmqEPWiiBvJfwyXrexzWJ
yPL+r7ZXc1+ltBL+Ope+b+AJfAffSr8/gbvv8wm+gXuegD65zyt8A4+DvL4v
wlfwAD66I/PSH3kKP4J7Xt6z5gcy0R+R
     "]]}, 
   {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJx1kDEKgDAMRYNTR4cMGYpU8R7tGTyC4OzVewSVmqEPWiiBvJfwyXrexzWJ
yPL+r7ZXc1+ltBL+Ope+b+AJfAffSr8/gbvv8wm+gXuegD65zyt8A4+DvL4v
wlfwAD66I/PSH3kKP4J7Xt6z5gcy0R+R
     "]]}},
  AspectRatio->NCache[
    Rational[3, 10], 0.3],
  DisplayFunction->((Print[#]; Null)& ),
  GridLines->NCache[{{
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2], 
      Rational[9, 2], 
      Rational[11, 2], 
      Rational[13, 2], 
      Rational[15, 2], 
      Rational[17, 2], 
      Rational[19, 2], 
      Rational[21, 2]}, {
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2]}}, {{0.5, 1.5, 2.5, 3.5, 4.5, 5.5, 6.5, 7.5, 8.5, 9.5, 
     10.5}, {0.5, 1.5, 2.5, 3.5}}],
  GridLinesStyle->Directive[
    RGBColor[0.67, 0.68, 0.86]],
  ImageSize->{627.9999999999995, Automatic},
  PlotRange->{{0.5, 10.5}, {0.5, 3.5}},
  PlotRangeClipping->True,
  Prolog->{{
     Hue[0.35, 1, 1], 
     RectangleBox[{0.8, 0.8}, {1.2, 1.2}]}, {
     Hue[1], 
     RectangleBox[{9.8, 0.8}, {10.2, 1.2}]}},
  Ticks->False]], "Print"]
}, Open  ]],

Cell["\<\
Here are all the 5x5 tours that start with the sequence {{1,1},{2,3},{1,5}} \
and end with the sequence {{5,3}, {3,2},{5,1},{4,3},{5,5}}\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"KnightTour", "[", 
   RowBox[{"5", ",", "5", ",", "   ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "5"}], "}"}]}], "}"}], ",", "    ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"5", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"3", ",", "2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"5", ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"4", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"5", ",", "5"}], "}"}]}], "}"}]}], "]"}], "//", 
  "Timing"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Solution \"\>", "\[InvisibleSpace]", "1", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "5"}], "}"}]}], "}"}]}],
  SequenceForm[
  "Solution ", 1, ": ", {{1, 1}, {2, 3}, {1, 5}, {3, 4}, {1, 3}, {2, 1}, {4, 
   2}, {5, 4}, {3, 5}, {1, 4}, {2, 2}, {4, 1}, {3, 3}, {2, 5}, {4, 4}, {5, 2},
    {3, 1}, {1, 2}, {2, 4}, {4, 5}, {5, 3}, {3, 2}, {5, 1}, {4, 3}, {5, 5}}],
  Editable->False]], "Print"],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0], AbsolutePointSize[7], PointBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7FFpDgeoBJQWcUCVF3BAVceBJg+jYfphtAAa
LYJGc6DJ4zKHkDtE0NSj24vLX+j+RrcHXR+6/ej2oocLLn8iwgEA2mAZVQ==

     "]]}, 
   {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7FFpDgeoBJQWcUCVF3BAVceBJg+jYfphtAAa
LYJGc6DJ4zKHkDtE0NSj24vLX+j+RrcHXR+6/ej2oocLLn8iwgEA2mAZVQ==

     "]]}},
  AspectRatio->1,
  DisplayFunction->((Print[#]; Null)& ),
  GridLines->NCache[{{
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2], 
      Rational[9, 2], 
      Rational[11, 2]}, {
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2], 
      Rational[9, 2], 
      Rational[11, 2]}}, {{0.5, 1.5, 2.5, 3.5, 4.5, 5.5}, {0.5, 1.5, 2.5, 3.5,
     4.5, 5.5}}],
  GridLinesStyle->Directive[
    RGBColor[0.67, 0.68, 0.86]],
  PlotRange->{{0.5, 5.5}, {0.5, 5.5}},
  PlotRangeClipping->True,
  Prolog->{{
     Hue[0.35, 1, 1], 
     RectangleBox[{0.8, 0.8}, {1.2, 1.2}]}, {
     Hue[1], 
     RectangleBox[{4.8, 4.8}, {5.2, 5.2}]}},
  Ticks->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Solution \"\>", "\[InvisibleSpace]", "2", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "5"}], "}"}]}], "}"}]}],
  SequenceForm[
  "Solution ", 2, ": ", {{1, 1}, {2, 3}, {1, 5}, {3, 4}, {1, 3}, {2, 5}, {4, 
   4}, {5, 2}, {3, 1}, {1, 2}, {2, 4}, {4, 5}, {3, 3}, {2, 1}, {4, 2}, {5, 4},
    {3, 5}, {1, 4}, {2, 2}, {4, 1}, {5, 3}, {3, 2}, {5, 1}, {4, 3}, {5, 5}}],
  Editable->False]], "Print"],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0], AbsolutePointSize[7], PointBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7FFpDgeoBJQWcUCVF3BAVceBJg9TD9MvgEbj
MhfdXnT70PURcgdMPS53iKDRHGjyuMzBFQ7o/sYVLuj2INwBAGzgGVU=
     "]]}, 
   {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7FFpDgeoBJQWcUCVF3BAVceBJg9TD9MvgEbj
MhfdXnT70PURcgdMPS53iKDRHGjyuMzBFQ7o/sYVLuj2INwBAGzgGVU=
     "]]}},
  AspectRatio->1,
  DisplayFunction->((Print[#]; Null)& ),
  GridLines->NCache[{{
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2], 
      Rational[9, 2], 
      Rational[11, 2]}, {
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2], 
      Rational[9, 2], 
      Rational[11, 2]}}, {{0.5, 1.5, 2.5, 3.5, 4.5, 5.5}, {0.5, 1.5, 2.5, 3.5,
     4.5, 5.5}}],
  GridLinesStyle->Directive[
    RGBColor[0.67, 0.68, 0.86]],
  PlotRange->{{0.5, 5.5}, {0.5, 5.5}},
  PlotRangeClipping->True,
  Prolog->{{
     Hue[0.35, 1, 1], 
     RectangleBox[{0.8, 0.8}, {1.2, 1.2}]}, {
     Hue[1], 
     RectangleBox[{4.8, 4.8}, {5.2, 5.2}]}},
  Ticks->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Solution \"\>", "\[InvisibleSpace]", "3", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "5"}], "}"}]}], "}"}]}],
  SequenceForm[
  "Solution ", 3, ": ", {{1, 1}, {2, 3}, {1, 5}, {3, 4}, {4, 2}, {2, 1}, {1, 
   3}, {2, 5}, {4, 4}, {5, 2}, {3, 1}, {1, 2}, {2, 4}, {4, 5}, {3, 3}, {5, 4},
    {3, 5}, {1, 4}, {2, 2}, {4, 1}, {5, 3}, {3, 2}, {5, 1}, {4, 3}, {5, 5}}],
  Editable->False]], "Print"],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0], AbsolutePointSize[7], PointBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7FFpDgeoBJQWcUCVF3DArk4ATR0DmjqYOMw8
dH0CaOLo9qLbh+4edH3o7uRAExdBo9Hl0f2By16YPnR/4fI3bncAAIFAGVU=

     "]]}, 
   {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7FFpDgeoBJQWcUCVF3DArk4ATR0DmjqYOMw8
dH0CaOLo9qLbh+4edH3o7uRAExdBo9Hl0f2By16YPnR/4fI3bncAAIFAGVU=

     "]]}},
  AspectRatio->1,
  DisplayFunction->((Print[#]; Null)& ),
  GridLines->NCache[{{
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2], 
      Rational[9, 2], 
      Rational[11, 2]}, {
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2], 
      Rational[9, 2], 
      Rational[11, 2]}}, {{0.5, 1.5, 2.5, 3.5, 4.5, 5.5}, {0.5, 1.5, 2.5, 3.5,
     4.5, 5.5}}],
  GridLinesStyle->Directive[
    RGBColor[0.67, 0.68, 0.86]],
  PlotRange->{{0.5, 5.5}, {0.5, 5.5}},
  PlotRangeClipping->True,
  Prolog->{{
     Hue[0.35, 1, 1], 
     RectangleBox[{0.8, 0.8}, {1.2, 1.2}]}, {
     Hue[1], 
     RectangleBox[{4.8, 4.8}, {5.2, 5.2}]}},
  Ticks->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Solution \"\>", "\[InvisibleSpace]", "4", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "5"}], "}"}]}], "}"}]}],
  SequenceForm[
  "Solution ", 4, ": ", {{1, 1}, {2, 3}, {1, 5}, {3, 4}, {4, 2}, {5, 4}, {3, 
   5}, {1, 4}, {2, 2}, {4, 1}, {3, 3}, {2, 1}, {1, 3}, {2, 5}, {4, 4}, {5, 2},
    {3, 1}, {1, 2}, {2, 4}, {4, 5}, {5, 3}, {3, 2}, {5, 1}, {4, 3}, {5, 5}}],
  Editable->False]], "Print"],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0], AbsolutePointSize[7], PointBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7FFpDgeoBJQWcUCVF3DArk4AjRZBoznQ5GHm
wfQzoImj28OBJs+AQxxmHy534fIXun/Q3YGuD9196Pbichd6OCDCCQBRABlV

     "]]}, 
   {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7FFpDgeoBJQWcUCVF3DArk4AjRZBoznQ5GHm
wfQzoImj28OBJs+AQxxmHy534fIXun/Q3YGuD9196Pbichd6OCDCCQBRABlV

     "]]}},
  AspectRatio->1,
  DisplayFunction->((Print[#]; Null)& ),
  GridLines->NCache[{{
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2], 
      Rational[9, 2], 
      Rational[11, 2]}, {
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2], 
      Rational[9, 2], 
      Rational[11, 2]}}, {{0.5, 1.5, 2.5, 3.5, 4.5, 5.5}, {0.5, 1.5, 2.5, 3.5,
     4.5, 5.5}}],
  GridLinesStyle->Directive[
    RGBColor[0.67, 0.68, 0.86]],
  PlotRange->{{0.5, 5.5}, {0.5, 5.5}},
  PlotRangeClipping->True,
  Prolog->{{
     Hue[0.35, 1, 1], 
     RectangleBox[{0.8, 0.8}, {1.2, 1.2}]}, {
     Hue[1], 
     RectangleBox[{4.8, 4.8}, {5.2, 5.2}]}},
  Ticks->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Solution \"\>", "\[InvisibleSpace]", "5", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "5"}], "}"}]}], "}"}]}],
  SequenceForm[
  "Solution ", 5, ": ", {{1, 1}, {2, 3}, {1, 5}, {3, 4}, {2, 2}, {1, 4}, {3, 
   5}, {5, 4}, {4, 2}, {2, 1}, {1, 3}, {2, 5}, {4, 4}, {5, 2}, {3, 1}, {1, 2},
    {2, 4}, {4, 5}, {3, 3}, {4, 1}, {5, 3}, {3, 2}, {5, 1}, {4, 3}, {5, 5}}],
  Editable->False]], "Print"],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0], AbsolutePointSize[7], PointBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7FFpDgeoBJQWcUCVF3DArg5GC6CpF0FTD5OH
iePSBxPnQBPHpU8ATRzd3ejuRfcPuj50f6K7A10e3V243I0rHEQcAEoAGVU=

     "]]}, 
   {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7FFpDgeoBJQWcUCVF3DArg5GC6CpF0FTD5OH
iePSBxPnQBPHpU8ATRzd3ejuRfcPuj50f6K7A10e3V243I0rHEQcAEoAGVU=

     "]]}},
  AspectRatio->1,
  DisplayFunction->((Print[#]; Null)& ),
  GridLines->NCache[{{
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2], 
      Rational[9, 2], 
      Rational[11, 2]}, {
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2], 
      Rational[9, 2], 
      Rational[11, 2]}}, {{0.5, 1.5, 2.5, 3.5, 4.5, 5.5}, {0.5, 1.5, 2.5, 3.5,
     4.5, 5.5}}],
  GridLinesStyle->Directive[
    RGBColor[0.67, 0.68, 0.86]],
  PlotRange->{{0.5, 5.5}, {0.5, 5.5}},
  PlotRangeClipping->True,
  Prolog->{{
     Hue[0.35, 1, 1], 
     RectangleBox[{0.8, 0.8}, {1.2, 1.2}]}, {
     Hue[1], 
     RectangleBox[{4.8, 4.8}, {5.2, 5.2}]}},
  Ticks->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Solution \"\>", "\[InvisibleSpace]", "6", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "5"}], "}"}]}], "}"}]}],
  SequenceForm[
  "Solution ", 6, ": ", {{1, 1}, {2, 3}, {1, 5}, {3, 4}, {2, 2}, {4, 1}, {3, 
   3}, {1, 4}, {3, 5}, {5, 4}, {4, 2}, {2, 1}, {1, 3}, {2, 5}, {4, 4}, {5, 2},
    {3, 1}, {1, 2}, {2, 4}, {4, 5}, {5, 3}, {3, 2}, {5, 1}, {4, 3}, {5, 5}}],
  Editable->False]], "Print"],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0], AbsolutePointSize[7], PointBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7FFpDgeoBJQWcUCVF3DAro6BgDoYLYCmTgSH
PEycAU0cpg8mzoEmjkufAJo4ur/Q/YPuD3R96P5DtxeXu3D5U8QBAIJAGVU=

     "]]}, 
   {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7FFpDgeoBJQWcUCVF3DAro6BgDoYLYCmTgSH
PEycAU0cpg8mzoEmjkufAJo4ur/Q/YPuD3R96P5DtxeXu3D5U8QBAIJAGVU=

     "]]}},
  AspectRatio->1,
  DisplayFunction->((Print[#]; Null)& ),
  GridLines->NCache[{{
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2], 
      Rational[9, 2], 
      Rational[11, 2]}, {
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2], 
      Rational[9, 2], 
      Rational[11, 2]}}, {{0.5, 1.5, 2.5, 3.5, 4.5, 5.5}, {0.5, 1.5, 2.5, 3.5,
     4.5, 5.5}}],
  GridLinesStyle->Directive[
    RGBColor[0.67, 0.68, 0.86]],
  PlotRange->{{0.5, 5.5}, {0.5, 5.5}},
  PlotRangeClipping->True,
  Prolog->{{
     Hue[0.35, 1, 1], 
     RectangleBox[{0.8, 0.8}, {1.2, 1.2}]}, {
     Hue[1], 
     RectangleBox[{4.8, 4.8}, {5.2, 5.2}]}},
  Ticks->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"All Done. I traversed \"\>", "\[InvisibleSpace]", "185", 
   "\[InvisibleSpace]", "\<\" paths. Solutions: \"\>", "\[InvisibleSpace]", 
   "6"}],
  SequenceForm["All Done. I traversed ", 185, " paths. Solutions: ", 6],
  Editable->False]], "Print"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.053377999999999926`", ",", "Null"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"path6", " ", "=", " \[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "5"}], "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"PlotTour", "[", "path6", "]"}]}], "Input"],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0], AbsolutePointSize[7], PointBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7FFpDgeoBJQWcUCVF3DAro6BgDoYLYCmTgSH
PEycAU0cpg8mzoEmjkufAJo4ur/Q/YPuD3R96P5DtxeXu3D5U8QBAIJAGVU=

     "]]}, 
   {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7FFpDgeoBJQWcUCVF3DAro6BgDoYLYCmTgSH
PEycAU0cpg8mzoEmjkufAJo4ur/Q/YPuD3R96P5DtxeXu3D5U8QBAIJAGVU=

     "]]}},
  AspectRatio->1,
  DisplayFunction->((Print[#]; Null)& ),
  GridLines->NCache[{{
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2], 
      Rational[9, 2], 
      Rational[11, 2]}, {
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2], 
      Rational[9, 2], 
      Rational[11, 2]}}, {{0.5, 1.5, 2.5, 3.5, 4.5, 5.5}, {0.5, 1.5, 2.5, 3.5,
     4.5, 5.5}}],
  GridLinesStyle->Directive[
    RGBColor[0.67, 0.68, 0.86]],
  PlotRange->{{0.5, 5.5}, {0.5, 5.5}},
  PlotRangeClipping->True,
  Prolog->{{
     Hue[0.35, 1, 1], 
     RectangleBox[{0.8, 0.8}, {1.2, 1.2}]}, {
     Hue[1], 
     RectangleBox[{4.8, 4.8}, {5.2, 5.2}]}},
  Ticks->False]], "Print"]
}, Open  ]],

Cell[TextData[{
 "Here is a 8x8 ",
 StyleBox["closed",
  FontColor->RGBColor[1, 0, 0]],
 " tour:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"path", " ", "=", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"8", ",", "4"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"7", ",", "2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"5", ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"6", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"4", ",", "4"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"3", ",", "2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", "3"}], "}"}], ",", "\[IndentingNewLine]", 
      "              ", 
      RowBox[{"{", 
       RowBox[{"1", ",", "5"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", "7"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"4", ",", "8"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"3", ",", "6"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"5", ",", "5"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"6", ",", "7"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"8", ",", "8"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"7", ",", "6"}], "}"}], ",", "\[IndentingNewLine]", 
      "              ", 
      RowBox[{"{", 
       RowBox[{"6", ",", "4"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"8", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"7", ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"5", ",", "2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"3", ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", "4"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"4", ",", "3"}], "}"}], ",", "\[IndentingNewLine]", 
      "              ", 
      RowBox[{"{", 
       RowBox[{"3", ",", "5"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "6"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", "8"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"4", ",", "7"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"6", ",", "8"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"8", ",", "7"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"7", ",", "5"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"5", ",", "6"}], "}"}], ",", "\[IndentingNewLine]", 
      "              ", 
      RowBox[{"{", 
       RowBox[{"3", ",", "7"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "8"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", "6"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"4", ",", "5"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"3", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "4"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", "2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"4", ",", "1"}], "}"}], ",", "\[IndentingNewLine]", 
      "              ", 
      RowBox[{"{", 
       RowBox[{"6", ",", "2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"8", ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"7", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"5", ",", "4"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"6", ",", "6"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"8", ",", "5"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"7", ",", "7"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"5", ",", "8"}], "}"}], ",", "\[IndentingNewLine]", 
      "              ", 
      RowBox[{"{", 
       RowBox[{"4", ",", "6"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"3", ",", "8"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "7"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", "5"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"4", ",", "2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"3", ",", "4"}], "}"}], ",", "\[IndentingNewLine]", 
      "              ", 
      RowBox[{"{", 
       RowBox[{"5", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"6", ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"8", ",", "2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"7", ",", "4"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"8", ",", "6"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"7", ",", "8"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"5", ",", "7"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"6", ",", "5"}], "}"}]}], "}"}]}], ";"}], 
  "\[IndentingNewLine]"}]], "Input"],

Cell[TextData[{
 "The ",
 StyleBox["PlotTour",
  FontFamily->"Courier"],
 " function detects that it is a ",
 StyleBox["closed",
  FontColor->RGBColor[1, 0, 0]],
 " tour, and so the green and red blobs are now not drawn, and the starting \
point is joined to the end point. Here is the default plot:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlotTour", "[", "path", "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0], AbsolutePointSize[7], PointBox[CompressedData["
1:eJyFkzEOwjAMRSOmjAwZMmQoJ6FcgSMgMffqHAFQ/AYeslKp+qr77fj/2JfH
cX+eSim3z/vF+Zz3iVtgCRyBr+vEFt81sO+/+WARj3ywitfEG/pPX9TnXOo0
4RBvE3bxsrrws77ct3URz3whnvlKfnYvvjfrIp754nimG751c34VEiefvJUv
mW7qWjd9dCFx8ofQvniOs3O9B6s5t27viX3zPNl378Fqzq3be/Kv+w07DjmP

     "]]}, 
   {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJyFkzEOwjAMRSOmjAwZMmQoJ6FcgSMgMffqHAFQ/AYeslKp+qr77fj/2JfH
cX+eSim3z/vF+Zz3iVtgCRyBr+vEFt81sO+/+WARj3ywitfEG/pPX9TnXOo0
4RBvE3bxsrrws77ct3URz3whnvlKfnYvvjfrIp754nimG751c34VEiefvJUv
mW7qWjd9dCFx8ofQvniOs3O9B6s5t27viX3zPNl378Fqzq3be/Kv+w07DjmP

     "]]}},
  AspectRatio->1,
  DisplayFunction->((Print[#]; Null)& ),
  GridLines->NCache[{{
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2], 
      Rational[9, 2], 
      Rational[11, 2], 
      Rational[13, 2], 
      Rational[15, 2], 
      Rational[17, 2]}, {
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2], 
      Rational[9, 2], 
      Rational[11, 2], 
      Rational[13, 2], 
      Rational[15, 2], 
      Rational[17, 2]}}, {{0.5, 1.5, 2.5, 3.5, 4.5, 5.5, 6.5, 7.5, 8.5}, {0.5,
     1.5, 2.5, 3.5, 4.5, 5.5, 6.5, 7.5, 8.5}}],
  GridLinesStyle->Directive[
    RGBColor[0.67, 0.68, 0.86]],
  PlotRange->{{0.5, 8.5}, {0.5, 8.5}},
  PlotRangeClipping->True,
  Ticks->False]], "Print"]
}, Open  ]]
}, Open  ]],

Cell["Here is the same plot with a custom dotsize (set to 0 here):", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlotTour", "[", 
  RowBox[{"path", ",", " ", "0"}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0], AbsolutePointSize[0], PointBox[CompressedData["
1:eJyFkzEOwjAMRSOmjAwZMmQoJ6FcgSMgMffqHAFQ/AYeslKp+qr77fj/2JfH
cX+eSim3z/vF+Zz3iVtgCRyBr+vEFt81sO+/+WARj3ywitfEG/pPX9TnXOo0
4RBvE3bxsrrws77ct3URz3whnvlKfnYvvjfrIp754nimG751c34VEiefvJUv
mW7qWjd9dCFx8ofQvniOs3O9B6s5t27viX3zPNl378Fqzq3be/Kv+w07DjmP

     "]]}, 
   {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJyFkzEOwjAMRSOmjAwZMmQoJ6FcgSMgMffqHAFQ/AYeslKp+qr77fj/2JfH
cX+eSim3z/vF+Zz3iVtgCRyBr+vEFt81sO+/+WARj3ywitfEG/pPX9TnXOo0
4RBvE3bxsrrws77ct3URz3whnvlKfnYvvjfrIp754nimG751c34VEiefvJUv
mW7qWjd9dCFx8ofQvniOs3O9B6s5t27viX3zPNl378Fqzq3be/Kv+w07DjmP

     "]]}},
  AspectRatio->1,
  DisplayFunction->((Print[#]; Null)& ),
  GridLines->NCache[{{
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2], 
      Rational[9, 2], 
      Rational[11, 2], 
      Rational[13, 2], 
      Rational[15, 2], 
      Rational[17, 2]}, {
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2], 
      Rational[9, 2], 
      Rational[11, 2], 
      Rational[13, 2], 
      Rational[15, 2], 
      Rational[17, 2]}}, {{0.5, 1.5, 2.5, 3.5, 4.5, 5.5, 6.5, 7.5, 8.5}, {0.5,
     1.5, 2.5, 3.5, 4.5, 5.5, 6.5, 7.5, 8.5}}],
  GridLinesStyle->Directive[
    RGBColor[0.67, 0.68, 0.86]],
  PlotRange->{{0.5, 8.5}, {0.5, 8.5}},
  PlotRangeClipping->True,
  Ticks->False]], "Print"]
}, Open  ]],

Cell[TextData[{
 "\nAs a final example, here are ALL the ",
 StyleBox["closed",
  FontSlant->"Italic"],
 " tours on a 3 x 10 board:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"KnightTour", "[", 
   RowBox[{"3", ",", "10", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "1"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"2", ",", "3"}], "}"}]}], "}"}], " ", ",", " ", 
    RowBox[{"{", 
     RowBox[{"3", ",", "2"}], "}"}]}], "]"}], " ", "//", " ", 
  "Timing"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Solution \"\>", "\[InvisibleSpace]", "1", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "2"}], "}"}]}], "}"}]}],
  SequenceForm[
  "Solution ", 1, ": ", {{1, 1}, {2, 3}, {3, 1}, {1, 2}, {2, 4}, {1, 6}, {3, 
   5}, {1, 4}, {2, 2}, {3, 4}, {2, 6}, {1, 8}, {2, 10}, {3, 8}, {1, 9}, {3, 
   10}, {2, 8}, {1, 10}, {3, 9}, {2, 7}, {1, 5}, {3, 6}, {1, 7}, {2, 9}, {3, 
   7}, {2, 5}, {3, 3}, {2, 1}, {1, 3}, {3, 2}}],
  Editable->False]], "Print"],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0], AbsolutePointSize[7], PointBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7FFpDgeohANx4gJo4hJo8iIOqPoF0ORh+hjQ
5GHqJdDkFdD0q+CQh+lXwqGeA009TL8KmnolNPUyaOpF0NRL4FCPbh4DmjxM
vQiaPAcajR5uxIp/sAcAxssh8A==
     "]]}, 
   {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7FFpDgeohANx4gJo4hJo8iIOqPoF0ORh+hjQ
5GHqJdDkFdD0q+CQh+lXwqGeA009TL8KmnolNPUyaOpF0NRL4FCPbh4DmjxM
vQiaPAcajR5uxIp/sAcAxssh8A==
     "]]}},
  AspectRatio->NCache[
    Rational[3, 10], 0.3],
  DisplayFunction->((Print[#]; Null)& ),
  GridLines->NCache[{{
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2], 
      Rational[9, 2], 
      Rational[11, 2], 
      Rational[13, 2], 
      Rational[15, 2], 
      Rational[17, 2], 
      Rational[19, 2], 
      Rational[21, 2]}, {
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2]}}, {{0.5, 1.5, 2.5, 3.5, 4.5, 5.5, 6.5, 7.5, 8.5, 9.5, 
     10.5}, {0.5, 1.5, 2.5, 3.5}}],
  GridLinesStyle->Directive[
    RGBColor[0.67, 0.68, 0.86]],
  PlotRange->{{0.5, 10.5}, {0.5, 3.5}},
  PlotRangeClipping->True,
  Ticks->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Solution \"\>", "\[InvisibleSpace]", "2", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "2"}], "}"}]}], "}"}]}],
  SequenceForm[
  "Solution ", 2, ": ", {{1, 1}, {2, 3}, {3, 1}, {1, 2}, {2, 4}, {1, 6}, {3, 
   5}, {1, 4}, {2, 2}, {3, 4}, {2, 6}, {3, 8}, {2, 10}, {1, 8}, {3, 9}, {1, 
   10}, {2, 8}, {3, 10}, {1, 9}, {2, 7}, {1, 5}, {3, 6}, {1, 7}, {2, 9}, {3, 
   7}, {2, 5}, {3, 3}, {2, 1}, {1, 3}, {3, 2}}],
  Editable->False]], "Print"],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0], AbsolutePointSize[7], PointBox[CompressedData["
1:eJyNkEEKgCAQRYdWLlu4cCFU0j30DB0haN3VO0JF/YUPBAX58N+bQVz2czsG
M5ue++Z3rlynKz8off2IPoD7Us+P4JozcPkBfAZfG1z7U8MXl2/g8hP8CN+D
672aj+DaZ+DyPbhD8t96+yvfjQsh8A==
     "]]}, 
   {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJyNkEEKgCAQRYdWLlu4cCFU0j30DB0haN3VO0JF/YUPBAX58N+bQVz2czsG
M5ue++Z3rlynKz8off2IPoD7Us+P4JozcPkBfAZfG1z7U8MXl2/g8hP8CN+D
672aj+DaZ+DyPbhD8t96+yvfjQsh8A==
     "]]}},
  AspectRatio->NCache[
    Rational[3, 10], 0.3],
  DisplayFunction->((Print[#]; Null)& ),
  GridLines->NCache[{{
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2], 
      Rational[9, 2], 
      Rational[11, 2], 
      Rational[13, 2], 
      Rational[15, 2], 
      Rational[17, 2], 
      Rational[19, 2], 
      Rational[21, 2]}, {
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2]}}, {{0.5, 1.5, 2.5, 3.5, 4.5, 5.5, 6.5, 7.5, 8.5, 9.5, 
     10.5}, {0.5, 1.5, 2.5, 3.5}}],
  GridLinesStyle->Directive[
    RGBColor[0.67, 0.68, 0.86]],
  PlotRange->{{0.5, 10.5}, {0.5, 3.5}},
  PlotRangeClipping->True,
  Ticks->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Solution \"\>", "\[InvisibleSpace]", "3", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "2"}], "}"}]}], "}"}]}],
  SequenceForm[
  "Solution ", 3, ": ", {{1, 1}, {2, 3}, {3, 1}, {1, 2}, {2, 4}, {1, 6}, {3, 
   5}, {2, 7}, {3, 9}, {1, 10}, {2, 8}, {3, 10}, {1, 9}, {3, 8}, {2, 10}, {1, 
   8}, {2, 6}, {1, 4}, {2, 2}, {3, 4}, {1, 5}, {3, 6}, {1, 7}, {2, 9}, {3, 
   7}, {2, 5}, {3, 3}, {2, 1}, {1, 3}, {3, 2}}],
  Editable->False]], "Print"],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0], AbsolutePointSize[7], PointBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7FFpDgeohANx4gJo4hJo8iIOqPpl0NQrocmr
oOlXQFOvgqZeCYd6dPNg+hXQ1EugyQugyTPgkIeZL4KmXgJNXgZNHuZeBjR5
dPMY0MRhNLq7iBX/YA8AuQsh8A==
     "]]}, 
   {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7FFpDgeohANx4gJo4hJo8iIOqPpl0NQrocmr
oOlXQFOvgqZeCYd6dPNg+hXQ1EugyQugyTPgkIeZL4KmXgJNXgZNHuZeBjR5
dPMY0MRhNLq7iBX/YA8AuQsh8A==
     "]]}},
  AspectRatio->NCache[
    Rational[3, 10], 0.3],
  DisplayFunction->((Print[#]; Null)& ),
  GridLines->NCache[{{
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2], 
      Rational[9, 2], 
      Rational[11, 2], 
      Rational[13, 2], 
      Rational[15, 2], 
      Rational[17, 2], 
      Rational[19, 2], 
      Rational[21, 2]}, {
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2]}}, {{0.5, 1.5, 2.5, 3.5, 4.5, 5.5, 6.5, 7.5, 8.5, 9.5, 
     10.5}, {0.5, 1.5, 2.5, 3.5}}],
  GridLinesStyle->Directive[
    RGBColor[0.67, 0.68, 0.86]],
  PlotRange->{{0.5, 10.5}, {0.5, 3.5}},
  PlotRangeClipping->True,
  Ticks->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Solution \"\>", "\[InvisibleSpace]", "4", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "2"}], "}"}]}], "}"}]}],
  SequenceForm[
  "Solution ", 4, ": ", {{1, 1}, {2, 3}, {3, 1}, {1, 2}, {2, 4}, {1, 6}, {3, 
   5}, {2, 7}, {1, 9}, {3, 10}, {2, 8}, {1, 10}, {3, 9}, {1, 8}, {2, 10}, {3, 
   8}, {2, 6}, {1, 4}, {2, 2}, {3, 4}, {1, 5}, {3, 6}, {1, 7}, {2, 9}, {3, 
   7}, {2, 5}, {3, 3}, {2, 1}, {1, 3}, {3, 2}}],
  Editable->False]], "Print"],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0], AbsolutePointSize[7], PointBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7FFpDgeohANx4gJo4hJo8iIOqPpl0NQroalX
QVOvgKZeBU29Eg716OYxoMnD1EugycP8A9PPgEMepl8ETb0EmrwMmjzMvQxo
8ujmMaCJw2h0dxEr/sEeAPLLIfA=
     "]]}, 
   {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7FFpDgeohANx4gJo4hJo8iIOqPpl0NQroalX
QVOvgKZeBU29Eg716OYxoMnD1EugycP8A9PPgEMepl8ETb0EmrwMmjzMvQxo
8ujmMaCJw2h0dxEr/sEeAPLLIfA=
     "]]}},
  AspectRatio->NCache[
    Rational[3, 10], 0.3],
  DisplayFunction->((Print[#]; Null)& ),
  GridLines->NCache[{{
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2], 
      Rational[9, 2], 
      Rational[11, 2], 
      Rational[13, 2], 
      Rational[15, 2], 
      Rational[17, 2], 
      Rational[19, 2], 
      Rational[21, 2]}, {
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2]}}, {{0.5, 1.5, 2.5, 3.5, 4.5, 5.5, 6.5, 7.5, 8.5, 9.5, 
     10.5}, {0.5, 1.5, 2.5, 3.5}}],
  GridLinesStyle->Directive[
    RGBColor[0.67, 0.68, 0.86]],
  PlotRange->{{0.5, 10.5}, {0.5, 3.5}},
  PlotRangeClipping->True,
  Ticks->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Solution \"\>", "\[InvisibleSpace]", "5", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "2"}], "}"}]}], "}"}]}],
  SequenceForm[
  "Solution ", 5, ": ", {{1, 1}, {2, 3}, {3, 1}, {1, 2}, {2, 4}, {3, 6}, {1, 
   5}, {2, 7}, {1, 9}, {3, 10}, {2, 8}, {1, 10}, {3, 9}, {1, 8}, {2, 10}, {3, 
   8}, {2, 6}, {3, 4}, {2, 2}, {1, 4}, {3, 5}, {1, 6}, {3, 7}, {2, 9}, {1, 
   7}, {2, 5}, {3, 3}, {2, 1}, {1, 3}, {3, 2}}],
  Editable->False]], "Print"],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0], AbsolutePointSize[7], PointBox[CompressedData["
1:eJyNjkEKgCAUBT+tXLpw4UKoxHvoGTqC0Lqre4SK+gsHpAR58GZ8uNZj2ycR
ma9753Na7tOUF5R/vUXvS+87+AF+BE94v8BP8OPA556Aq+/BLbgMuO47+B48
gOt/dS/Ad+AGqR75V9/yCZwrIfA=
     "]]}, 
   {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJyNjkEKgCAUBT+tXLpw4UKoxHvoGTqC0Lqre4SK+gsHpAR58GZ8uNZj2ycR
ma9753Na7tOUF5R/vUXvS+87+AF+BE94v8BP8OPA556Aq+/BLbgMuO47+B48
gOt/dS/Ad+AGqR75V9/yCZwrIfA=
     "]]}},
  AspectRatio->NCache[
    Rational[3, 10], 0.3],
  DisplayFunction->((Print[#]; Null)& ),
  GridLines->NCache[{{
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2], 
      Rational[9, 2], 
      Rational[11, 2], 
      Rational[13, 2], 
      Rational[15, 2], 
      Rational[17, 2], 
      Rational[19, 2], 
      Rational[21, 2]}, {
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2]}}, {{0.5, 1.5, 2.5, 3.5, 4.5, 5.5, 6.5, 7.5, 8.5, 9.5, 
     10.5}, {0.5, 1.5, 2.5, 3.5}}],
  GridLinesStyle->Directive[
    RGBColor[0.67, 0.68, 0.86]],
  PlotRange->{{0.5, 10.5}, {0.5, 3.5}},
  PlotRangeClipping->True,
  Ticks->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Solution \"\>", "\[InvisibleSpace]", "6", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "2"}], "}"}]}], "}"}]}],
  SequenceForm[
  "Solution ", 6, ": ", {{1, 1}, {2, 3}, {3, 1}, {1, 2}, {2, 4}, {3, 6}, {1, 
   5}, {2, 7}, {3, 9}, {1, 10}, {2, 8}, {3, 10}, {1, 9}, {3, 8}, {2, 10}, {1, 
   8}, {2, 6}, {3, 4}, {2, 2}, {1, 4}, {3, 5}, {1, 6}, {3, 7}, {2, 9}, {1, 
   7}, {2, 5}, {3, 3}, {2, 1}, {1, 3}, {3, 2}}],
  Editable->False]], "Print"],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0], AbsolutePointSize[7], PointBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7FFpDgeohANx4gJo4hIOqOpF0NTLoKlXQlOv
gqZeAU29Cpp6JRzq0c2D6VdAUy+BJg/zD7p/0eVh+kXQ1EugycugycPcCzNP
Bk29CJo8BxoNU4cuT0j8gz0AYmsh8A==
     "]]}, 
   {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7FFpDgeohANx4gJo4hIOqOpF0NTLoKlXQlOv
gqZeAU29Cpp6JRzq0c2D6VdAUy+BJg/zD7p/0eVh+kXQ1EugycugycPcCzNP
Bk29CJo8BxoNU4cuT0j8gz0AYmsh8A==
     "]]}},
  AspectRatio->NCache[
    Rational[3, 10], 0.3],
  DisplayFunction->((Print[#]; Null)& ),
  GridLines->NCache[{{
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2], 
      Rational[9, 2], 
      Rational[11, 2], 
      Rational[13, 2], 
      Rational[15, 2], 
      Rational[17, 2], 
      Rational[19, 2], 
      Rational[21, 2]}, {
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2]}}, {{0.5, 1.5, 2.5, 3.5, 4.5, 5.5, 6.5, 7.5, 8.5, 9.5, 
     10.5}, {0.5, 1.5, 2.5, 3.5}}],
  GridLinesStyle->Directive[
    RGBColor[0.67, 0.68, 0.86]],
  PlotRange->{{0.5, 10.5}, {0.5, 3.5}},
  PlotRangeClipping->True,
  Ticks->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Solution \"\>", "\[InvisibleSpace]", "7", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "2"}], "}"}]}], "}"}]}],
  SequenceForm[
  "Solution ", 7, ": ", {{1, 1}, {2, 3}, {3, 1}, {1, 2}, {2, 4}, {3, 6}, {1, 
   5}, {3, 4}, {2, 2}, {1, 4}, {2, 6}, {1, 8}, {2, 10}, {3, 8}, {1, 9}, {3, 
   10}, {2, 8}, {1, 10}, {3, 9}, {2, 7}, {3, 5}, {1, 6}, {3, 7}, {2, 9}, {1, 
   7}, {2, 5}, {3, 3}, {2, 1}, {1, 3}, {3, 2}}],
  Editable->False]], "Print"],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0], AbsolutePointSize[7], PointBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7FFpDgeohANx4gJo4hIOqOpFcKhHNw9GC6Cp
l0CTV0CTV8EhDzNfCYd6DjT1MP0qaOqV0NTLoKkXQZOHuRemXwZNHmYeTL8M
mnoRNHkONBqmDl2ekPgHewBwKyHw
     "]]}, 
   {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7FFpDgeohANx4gJo4hIOqOpFcKhHNw9GC6Cp
l0CTV0CTV8EhDzNfCYd6DjT1MP0qaOqV0NTLoKkXQZOHuRemXwZNHmYeTL8M
mnoRNHkONBqmDl2ekPgHewBwKyHw
     "]]}},
  AspectRatio->NCache[
    Rational[3, 10], 0.3],
  DisplayFunction->((Print[#]; Null)& ),
  GridLines->NCache[{{
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2], 
      Rational[9, 2], 
      Rational[11, 2], 
      Rational[13, 2], 
      Rational[15, 2], 
      Rational[17, 2], 
      Rational[19, 2], 
      Rational[21, 2]}, {
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2]}}, {{0.5, 1.5, 2.5, 3.5, 4.5, 5.5, 6.5, 7.5, 8.5, 9.5, 
     10.5}, {0.5, 1.5, 2.5, 3.5}}],
  GridLinesStyle->Directive[
    RGBColor[0.67, 0.68, 0.86]],
  PlotRange->{{0.5, 10.5}, {0.5, 3.5}},
  PlotRangeClipping->True,
  Ticks->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Solution \"\>", "\[InvisibleSpace]", "8", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "2"}], "}"}]}], "}"}]}],
  SequenceForm[
  "Solution ", 8, ": ", {{1, 1}, {2, 3}, {3, 1}, {1, 2}, {2, 4}, {3, 6}, {1, 
   5}, {3, 4}, {2, 2}, {1, 4}, {2, 6}, {3, 8}, {2, 10}, {1, 8}, {3, 9}, {1, 
   10}, {2, 8}, {3, 10}, {1, 9}, {2, 7}, {3, 5}, {1, 6}, {3, 7}, {2, 9}, {1, 
   7}, {2, 5}, {3, 3}, {2, 1}, {1, 3}, {3, 2}}],
  Editable->False]], "Print"],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0], AbsolutePointSize[7], PointBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7FFpDgeohANx4gJo4hIOqOpFcKhHNw9GC6Cp
l0CTV0DTr4JDHqZfCYd6mDxMPQOaPEy9Epp6GTT1ImjqJXCoRzcPpl8GTb0I
mjwHGg1Thy5PSPyDPQA2ayHw
     "]]}, 
   {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7FFpDgeohANx4gJo4hIOqOpFcKhHNw9GC6Cp
l0CTV0DTr4JDHqZfCYd6mDxMPQOaPEy9Epp6GTT1ImjqJXCoRzcPpl8GTb0I
mjwHGg1Thy5PSPyDPQA2ayHw
     "]]}},
  AspectRatio->NCache[
    Rational[3, 10], 0.3],
  DisplayFunction->((Print[#]; Null)& ),
  GridLines->NCache[{{
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2], 
      Rational[9, 2], 
      Rational[11, 2], 
      Rational[13, 2], 
      Rational[15, 2], 
      Rational[17, 2], 
      Rational[19, 2], 
      Rational[21, 2]}, {
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2]}}, {{0.5, 1.5, 2.5, 3.5, 4.5, 5.5, 6.5, 7.5, 8.5, 9.5, 
     10.5}, {0.5, 1.5, 2.5, 3.5}}],
  GridLinesStyle->Directive[
    RGBColor[0.67, 0.68, 0.86]],
  PlotRange->{{0.5, 10.5}, {0.5, 3.5}},
  PlotRangeClipping->True,
  Ticks->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Solution \"\>", "\[InvisibleSpace]", "9", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "2"}], "}"}]}], "}"}]}],
  SequenceForm[
  "Solution ", 9, ": ", {{1, 1}, {2, 3}, {3, 1}, {1, 2}, {3, 3}, {2, 1}, {1, 
   3}, {2, 5}, {1, 7}, {2, 9}, {3, 7}, {1, 6}, {3, 5}, {1, 4}, {2, 2}, {3, 
   4}, {2, 6}, {1, 8}, {2, 10}, {3, 8}, {1, 9}, {3, 10}, {2, 8}, {1, 10}, {3, 
   9}, {2, 7}, {1, 5}, {3, 6}, {2, 4}, {3, 2}}],
  Editable->False]], "Print"],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0], AbsolutePointSize[7], PointBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7FFpDgeohANp4hxo4gw4xEXQzJFBk1fCIQ8z
RwKHeTB5ARzuYECTRzcPJq+Apl8FhzxMvxIO9Rxo6mH6VdDUK6Gpl0FTL4Km
XgJNvQCaelzh/sEeAMw6IfA=
     "]]}, 
   {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7FFpDgeohANp4hxo4gw4xEXQzJFBk1fCIQ8z
RwKHeTB5ARzuYECTRzcPJq+Apl8FhzxMvxIO9Rxo6mH6VdDUK6Gpl0FTL4Km
XgJNvQCaelzh/sEeAMw6IfA=
     "]]}},
  AspectRatio->NCache[
    Rational[3, 10], 0.3],
  DisplayFunction->((Print[#]; Null)& ),
  GridLines->NCache[{{
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2], 
      Rational[9, 2], 
      Rational[11, 2], 
      Rational[13, 2], 
      Rational[15, 2], 
      Rational[17, 2], 
      Rational[19, 2], 
      Rational[21, 2]}, {
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2]}}, {{0.5, 1.5, 2.5, 3.5, 4.5, 5.5, 6.5, 7.5, 8.5, 9.5, 
     10.5}, {0.5, 1.5, 2.5, 3.5}}],
  GridLinesStyle->Directive[
    RGBColor[0.67, 0.68, 0.86]],
  PlotRange->{{0.5, 10.5}, {0.5, 3.5}},
  PlotRangeClipping->True,
  Ticks->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Solution \"\>", "\[InvisibleSpace]", "10", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "2"}], "}"}]}], "}"}]}],
  SequenceForm[
  "Solution ", 10, ": ", {{1, 1}, {2, 3}, {3, 1}, {1, 2}, {3, 3}, {2, 1}, {1, 
   3}, {2, 5}, {1, 7}, {2, 9}, {3, 7}, {1, 6}, {3, 5}, {1, 4}, {2, 2}, {3, 
   4}, {2, 6}, {3, 8}, {2, 10}, {1, 8}, {3, 9}, {1, 10}, {2, 8}, {3, 10}, {1, 
   9}, {2, 7}, {1, 5}, {3, 6}, {2, 4}, {3, 2}}],
  Editable->False]], "Print"],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0], AbsolutePointSize[7], PointBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7FFpDgeohANp4hxo4gw4xEXQzJFBk1fCIQ8z
RwKHeTB5ARzuYECTRzcPJq+AJq+CQx7dvejqYfIw9Qxo8jD1SmjqZdDUi6DJ
w9yL7l90f6KH+wd7AJJ6IfA=
     "]]}, 
   {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7FFpDgeohANp4hxo4gw4xEXQzJFBk1fCIQ8z
RwKHeTB5ARzuYECTRzcPJq+AJq+CQx7dvejqYfIw9Qxo8jD1SmjqZdDUi6DJ
w9yL7l90f6KH+wd7AJJ6IfA=
     "]]}},
  AspectRatio->NCache[
    Rational[3, 10], 0.3],
  DisplayFunction->((Print[#]; Null)& ),
  GridLines->NCache[{{
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2], 
      Rational[9, 2], 
      Rational[11, 2], 
      Rational[13, 2], 
      Rational[15, 2], 
      Rational[17, 2], 
      Rational[19, 2], 
      Rational[21, 2]}, {
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2]}}, {{0.5, 1.5, 2.5, 3.5, 4.5, 5.5, 6.5, 7.5, 8.5, 9.5, 
     10.5}, {0.5, 1.5, 2.5, 3.5}}],
  GridLinesStyle->Directive[
    RGBColor[0.67, 0.68, 0.86]],
  PlotRange->{{0.5, 10.5}, {0.5, 3.5}},
  PlotRangeClipping->True,
  Ticks->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Solution \"\>", "\[InvisibleSpace]", "11", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "2"}], "}"}]}], "}"}]}],
  SequenceForm[
  "Solution ", 11, ": ", {{1, 1}, {2, 3}, {3, 1}, {1, 2}, {3, 3}, {2, 1}, {1, 
   3}, {2, 5}, {1, 7}, {2, 9}, {3, 7}, {1, 6}, {3, 5}, {2, 7}, {3, 9}, {1, 
   10}, {2, 8}, {3, 10}, {1, 9}, {3, 8}, {2, 10}, {1, 8}, {2, 6}, {1, 4}, {2, 
   2}, {3, 4}, {1, 5}, {3, 6}, {2, 4}, {3, 2}}],
  Editable->False]], "Print"],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0], AbsolutePointSize[7], PointBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7FFpDgeohANp4hxo4gw4xEXQzJFBk1fCIQ8z
RwKHeRxo6mH6ldDkVdD0K6CpV0FTr4RDPbp5MP0KaOol0OQF0OQZcMjDzBdB
Uy+BJg9Tj24Oerh/sAcAvnoh8A==
     "]]}, 
   {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7FFpDgeohANp4hxo4gw4xEXQzJFBk1fCIQ8z
RwKHeRxo6mH6ldDkVdD0K6CpV0FTr4RDPbp5MP0KaOol0OQF0OQZcMjDzBdB
Uy+BJg9Tj24Oerh/sAcAvnoh8A==
     "]]}},
  AspectRatio->NCache[
    Rational[3, 10], 0.3],
  DisplayFunction->((Print[#]; Null)& ),
  GridLines->NCache[{{
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2], 
      Rational[9, 2], 
      Rational[11, 2], 
      Rational[13, 2], 
      Rational[15, 2], 
      Rational[17, 2], 
      Rational[19, 2], 
      Rational[21, 2]}, {
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2]}}, {{0.5, 1.5, 2.5, 3.5, 4.5, 5.5, 6.5, 7.5, 8.5, 9.5, 
     10.5}, {0.5, 1.5, 2.5, 3.5}}],
  GridLinesStyle->Directive[
    RGBColor[0.67, 0.68, 0.86]],
  PlotRange->{{0.5, 10.5}, {0.5, 3.5}},
  PlotRangeClipping->True,
  Ticks->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Solution \"\>", "\[InvisibleSpace]", "12", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "2"}], "}"}]}], "}"}]}],
  SequenceForm[
  "Solution ", 12, ": ", {{1, 1}, {2, 3}, {3, 1}, {1, 2}, {3, 3}, {2, 1}, {1, 
   3}, {2, 5}, {1, 7}, {2, 9}, {3, 7}, {1, 6}, {3, 5}, {2, 7}, {1, 9}, {3, 
   10}, {2, 8}, {1, 10}, {3, 9}, {1, 8}, {2, 10}, {3, 8}, {2, 6}, {1, 4}, {2, 
   2}, {3, 4}, {1, 5}, {3, 6}, {2, 4}, {3, 2}}],
  Editable->False]], "Print"],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0], AbsolutePointSize[7], PointBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7FFpDgeohANp4hxo4gw4xEXQzJFBk1fCIQ8z
RwKHeRxo6mH6ldDUq6CpV0BTr4KmXgmHenTzGNDk0d0LkxdA08+AQx6mXwRN
vQSaPEw9ujno4f7BHgD4OiHw
     "]]}, 
   {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7FFpDgeohANp4hxo4gw4xEXQzJFBk1fCIQ8z
RwKHeRxo6mH6ldDUq6CpV0BTr4KmXgmHenTzGNDk0d0LkxdA08+AQx6mXwRN
vQSaPEw9ujno4f7BHgD4OiHw
     "]]}},
  AspectRatio->NCache[
    Rational[3, 10], 0.3],
  DisplayFunction->((Print[#]; Null)& ),
  GridLines->NCache[{{
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2], 
      Rational[9, 2], 
      Rational[11, 2], 
      Rational[13, 2], 
      Rational[15, 2], 
      Rational[17, 2], 
      Rational[19, 2], 
      Rational[21, 2]}, {
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2]}}, {{0.5, 1.5, 2.5, 3.5, 4.5, 5.5, 6.5, 7.5, 8.5, 9.5, 
     10.5}, {0.5, 1.5, 2.5, 3.5}}],
  GridLinesStyle->Directive[
    RGBColor[0.67, 0.68, 0.86]],
  PlotRange->{{0.5, 10.5}, {0.5, 3.5}},
  PlotRangeClipping->True,
  Ticks->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Solution \"\>", "\[InvisibleSpace]", "13", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "2"}], "}"}]}], "}"}]}],
  SequenceForm[
  "Solution ", 13, ": ", {{1, 1}, {2, 3}, {3, 1}, {1, 2}, {3, 3}, {2, 1}, {1, 
   3}, {2, 5}, {3, 7}, {2, 9}, {1, 7}, {3, 6}, {1, 5}, {2, 7}, {1, 9}, {3, 
   10}, {2, 8}, {1, 10}, {3, 9}, {1, 8}, {2, 10}, {3, 8}, {2, 6}, {3, 4}, {2, 
   2}, {1, 4}, {3, 5}, {1, 6}, {2, 4}, {3, 2}}],
  Editable->False]], "Print"],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0], AbsolutePointSize[7], PointBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7FFpDgeohANp4hxo4gw4xEXQzJFBU6eEQx6m
XwJNvQiaPEw9TL8SmrwKmn4FNPUqaOqVcKhHN48BTR6mXgJNXgBNngGHPHp4
oZsHk4epRzcHPdw/2AMAoZoh8A==
     "]]}, 
   {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7FFpDgeohANp4hxo4gw4xEXQzJFBU6eEQx6m
XwJNvQiaPEw9TL8SmrwKmn4FNPUqaOqVcKhHN48BTR6mXgJNXgBNngGHPHp4
oZsHk4epRzcHPdw/2AMAoZoh8A==
     "]]}},
  AspectRatio->NCache[
    Rational[3, 10], 0.3],
  DisplayFunction->((Print[#]; Null)& ),
  GridLines->NCache[{{
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2], 
      Rational[9, 2], 
      Rational[11, 2], 
      Rational[13, 2], 
      Rational[15, 2], 
      Rational[17, 2], 
      Rational[19, 2], 
      Rational[21, 2]}, {
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2]}}, {{0.5, 1.5, 2.5, 3.5, 4.5, 5.5, 6.5, 7.5, 8.5, 9.5, 
     10.5}, {0.5, 1.5, 2.5, 3.5}}],
  GridLinesStyle->Directive[
    RGBColor[0.67, 0.68, 0.86]],
  PlotRange->{{0.5, 10.5}, {0.5, 3.5}},
  PlotRangeClipping->True,
  Ticks->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Solution \"\>", "\[InvisibleSpace]", "14", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "2"}], "}"}]}], "}"}]}],
  SequenceForm[
  "Solution ", 14, ": ", {{1, 1}, {2, 3}, {3, 1}, {1, 2}, {3, 3}, {2, 1}, {1, 
   3}, {2, 5}, {3, 7}, {2, 9}, {1, 7}, {3, 6}, {1, 5}, {2, 7}, {3, 9}, {1, 
   10}, {2, 8}, {3, 10}, {1, 9}, {3, 8}, {2, 10}, {1, 8}, {2, 6}, {3, 4}, {2, 
   2}, {1, 4}, {3, 5}, {1, 6}, {2, 4}, {3, 2}}],
  Editable->False]], "Print"],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0], AbsolutePointSize[7], PointBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7FFpDgeohANp4hxo4gw4xEXQzJFBU6eEQx6m
XwJNvQiaPEw9TL8SmnoVNPUKaOpV0NQr4VCPbh5MvwKaegk0eQE0/Qw45NHD
C6ZeAk0eph7dHPRw/2APAGfaIfA=
     "]]}, 
   {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7FFpDgeohANp4hxo4gw4xEXQzJFBU6eEQx6m
XwJNvQiaPEw9TL8SmnoVNPUKaOpV0NQr4VCPbh5MvwKaegk0eQE0/Qw45NHD
C6ZeAk0eph7dHPRw/2APAGfaIfA=
     "]]}},
  AspectRatio->NCache[
    Rational[3, 10], 0.3],
  DisplayFunction->((Print[#]; Null)& ),
  GridLines->NCache[{{
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2], 
      Rational[9, 2], 
      Rational[11, 2], 
      Rational[13, 2], 
      Rational[15, 2], 
      Rational[17, 2], 
      Rational[19, 2], 
      Rational[21, 2]}, {
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2]}}, {{0.5, 1.5, 2.5, 3.5, 4.5, 5.5, 6.5, 7.5, 8.5, 9.5, 
     10.5}, {0.5, 1.5, 2.5, 3.5}}],
  GridLinesStyle->Directive[
    RGBColor[0.67, 0.68, 0.86]],
  PlotRange->{{0.5, 10.5}, {0.5, 3.5}},
  PlotRangeClipping->True,
  Ticks->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Solution \"\>", "\[InvisibleSpace]", "15", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "2"}], "}"}]}], "}"}]}],
  SequenceForm[
  "Solution ", 15, ": ", {{1, 1}, {2, 3}, {3, 1}, {1, 2}, {3, 3}, {2, 1}, {1, 
   3}, {2, 5}, {3, 7}, {2, 9}, {1, 7}, {3, 6}, {1, 5}, {3, 4}, {2, 2}, {1, 
   4}, {2, 6}, {1, 8}, {2, 10}, {3, 8}, {1, 9}, {3, 10}, {2, 8}, {1, 10}, {3, 
   9}, {2, 7}, {3, 5}, {1, 6}, {2, 4}, {3, 2}}],
  Editable->False]], "Print"],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0], AbsolutePointSize[7], PointBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7FFpDgeohANp4hxo4gw4xEXQzJFBU6eEQx6m
XwJNvQiavACaPAMaLYCmXgJNXgFNXgWHPLp70dVzoKmH6VdBU6+Epl4GTb0I
mjzMvej+Rfcnerh/sAcAdZoh8A==
     "]]}, 
   {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7FFpDgeohANp4hxo4gw4xEXQzJFBU6eEQx6m
XwJNvQiavACaPAMaLYCmXgJNXgFNXgWHPLp70dVzoKmH6VdBU6+Epl4GTb0I
mjzMvej+Rfcnerh/sAcAdZoh8A==
     "]]}},
  AspectRatio->NCache[
    Rational[3, 10], 0.3],
  DisplayFunction->((Print[#]; Null)& ),
  GridLines->NCache[{{
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2], 
      Rational[9, 2], 
      Rational[11, 2], 
      Rational[13, 2], 
      Rational[15, 2], 
      Rational[17, 2], 
      Rational[19, 2], 
      Rational[21, 2]}, {
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2]}}, {{0.5, 1.5, 2.5, 3.5, 4.5, 5.5, 6.5, 7.5, 8.5, 9.5, 
     10.5}, {0.5, 1.5, 2.5, 3.5}}],
  GridLinesStyle->Directive[
    RGBColor[0.67, 0.68, 0.86]],
  PlotRange->{{0.5, 10.5}, {0.5, 3.5}},
  PlotRangeClipping->True,
  Ticks->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Solution \"\>", "\[InvisibleSpace]", "16", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "2"}], "}"}]}], "}"}]}],
  SequenceForm[
  "Solution ", 16, ": ", {{1, 1}, {2, 3}, {3, 1}, {1, 2}, {3, 3}, {2, 1}, {1, 
   3}, {2, 5}, {3, 7}, {2, 9}, {1, 7}, {3, 6}, {1, 5}, {3, 4}, {2, 2}, {1, 
   4}, {2, 6}, {3, 8}, {2, 10}, {1, 8}, {3, 9}, {1, 10}, {2, 8}, {3, 10}, {1, 
   9}, {2, 7}, {3, 5}, {1, 6}, {2, 4}, {3, 2}}],
  Editable->False]], "Print"],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0], AbsolutePointSize[7], PointBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7FFpDgeohANp4hxo4gw4xEXQzJFBU6eEQx6m
XwJNvQiavACaPAMaLYCmXgJNXgFNvwoOeZh+JRzqYfIw9Qxo8uj+hamXQVMv
gqZeAk29AJp6XOH+wR4AO9oh8A==
     "]]}, 
   {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7FFpDgeohANp4hxo4gw4xEXQzJFBU6eEQx6m
XwJNvQiavACaPAMaLYCmXgJNXgFNvwoOeZh+JRzqYfIw9Qxo8uj+hamXQVMv
gqZeAk29AJp6XOH+wR4AO9oh8A==
     "]]}},
  AspectRatio->NCache[
    Rational[3, 10], 0.3],
  DisplayFunction->((Print[#]; Null)& ),
  GridLines->NCache[{{
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2], 
      Rational[9, 2], 
      Rational[11, 2], 
      Rational[13, 2], 
      Rational[15, 2], 
      Rational[17, 2], 
      Rational[19, 2], 
      Rational[21, 2]}, {
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2]}}, {{0.5, 1.5, 2.5, 3.5, 4.5, 5.5, 6.5, 7.5, 8.5, 9.5, 
     10.5}, {0.5, 1.5, 2.5, 3.5}}],
  GridLinesStyle->Directive[
    RGBColor[0.67, 0.68, 0.86]],
  PlotRange->{{0.5, 10.5}, {0.5, 3.5}},
  PlotRangeClipping->True,
  Ticks->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"All Done. I traversed \"\>", "\[InvisibleSpace]", "261623", 
   "\[InvisibleSpace]", "\<\" paths. Solutions: \"\>", "\[InvisibleSpace]", 
   "16"}],
  SequenceForm["All Done. I traversed ", 261623, " paths. Solutions: ", 16],
  Editable->False]], "Print"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"12.556485000000002`", ",", "Null"}], "}"}]], "Output"]
}, Open  ]],

Cell["Here is a plot of the 15th and 16th solutions:", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"path15", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "2"}], "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"path16", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "2"}], "}"}]}], "}"}]}], ";"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"PlotTour", "[", 
  RowBox[{"path15", ",", "0"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"PlotTour", "[", 
  RowBox[{"path16", ",", "0"}], "]"}]}], "Input"],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0], AbsolutePointSize[0], PointBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7FFpDgeohANp4hxo4gw4xEXQzJFBU6eEQx6m
XwJNvQiavACaPAMaLYCmXgJNXgFNXgWHPLp70dVzoKmH6VdBU6+Epl4GTb0I
mjzMvej+Rfcnerh/sAcAdZoh8A==
     "]]}, 
   {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7FFpDgeohANp4hxo4gw4xEXQzJFBU6eEQx6m
XwJNvQiavACaPAMaLYCmXgJNXgFNXgWHPLp70dVzoKmH6VdBU6+Epl4GTb0I
mjzMvej+Rfcnerh/sAcAdZoh8A==
     "]]}},
  AspectRatio->NCache[
    Rational[3, 10], 0.3],
  DisplayFunction->((Print[#]; Null)& ),
  GridLines->NCache[{{
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2], 
      Rational[9, 2], 
      Rational[11, 2], 
      Rational[13, 2], 
      Rational[15, 2], 
      Rational[17, 2], 
      Rational[19, 2], 
      Rational[21, 2]}, {
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2]}}, {{0.5, 1.5, 2.5, 3.5, 4.5, 5.5, 6.5, 7.5, 8.5, 9.5, 
     10.5}, {0.5, 1.5, 2.5, 3.5}}],
  GridLinesStyle->Directive[
    RGBColor[0.67, 0.68, 0.86]],
  PlotRange->{{0.5, 10.5}, {0.5, 3.5}},
  PlotRangeClipping->True,
  Ticks->False]], "Print"],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0], AbsolutePointSize[0], PointBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7FFpDgeohANp4hxo4gw4xEXQzJFBU6eEQx6m
XwJNvQiavACaPAMaLYCmXgJNXgFNvwoOeZh+JRzqYfIw9Qxo8uj+hamXQVMv
gqZeAk29AJp6XOH+wR4AO9oh8A==
     "]]}, 
   {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7FFpDgeohANp4hxo4gw4xEXQzJFBU6eEQx6m
XwJNvQiavACaPAMaLYCmXgJNXgFNvwoOeZh+JRzqYfIw9Qxo8uj+hamXQVMv
gqZeAk29AJp6XOH+wR4AO9oh8A==
     "]]}},
  AspectRatio->NCache[
    Rational[3, 10], 0.3],
  DisplayFunction->((Print[#]; Null)& ),
  GridLines->NCache[{{
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2], 
      Rational[9, 2], 
      Rational[11, 2], 
      Rational[13, 2], 
      Rational[15, 2], 
      Rational[17, 2], 
      Rational[19, 2], 
      Rational[21, 2]}, {
      Rational[1, 2], 
      Rational[3, 2], 
      Rational[5, 2], 
      Rational[7, 2]}}, {{0.5, 1.5, 2.5, 3.5, 4.5, 5.5, 6.5, 7.5, 8.5, 9.5, 
     10.5}, {0.5, 1.5, 2.5, 3.5}}],
  GridLinesStyle->Directive[
    RGBColor[0.67, 0.68, 0.86]],
  PlotRange->{{0.5, 10.5}, {0.5, 3.5}},
  PlotRangeClipping->True,
  Ticks->False]], "Print"]
}, Open  ]],

Cell["", "Text"],

Cell["\<\
On a 3 x 8 board, starting from square {2,2}, there are 48 solutions:    (the \
1 at the end suppresses the printing/plotting of each solution)\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"KnightTour", "[", 
   RowBox[{"3", ",", "8", ",", 
    RowBox[{"{", 
     RowBox[{"2", ",", "2"}], "}"}], ",", "1"}], "]"}], " ", "//", " ", 
  "Timing"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"All Done. I traversed \"\>", "\[InvisibleSpace]", "26724", 
   "\[InvisibleSpace]", "\<\" paths. Solutions: \"\>", "\[InvisibleSpace]", 
   "48"}],
  SequenceForm["All Done. I traversed ", 26724, " paths. Solutions: ", 48],
  Editable->False]], "Print"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1.2208170000000003`", ",", "Null"}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]]
},
CellGrouping->Manual,
WindowSize->{1137, 936},
WindowMargins->{{19, Automatic}, {Automatic, 0}},
Hyphenation->False,
Magnification->1.25,
FrontEndVersion->"7.0 for Mac OS X x86 (32-bit) (February 18, 2009)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 264, 7, 65, "Subtitle"],
Cell[812, 29, 551, 19, 73, "Text"],
Cell[CellGroupData[{
Cell[1388, 52, 91, 2, 83, "Section"],
Cell[1482, 56, 2142, 54, 126, "Text"],
Cell[3627, 112, 1031, 25, 70, "Text"],
Cell[4661, 139, 2166, 50, 494, "Input"],
Cell[6830, 191, 1105, 29, 70, "Text"],
Cell[7938, 222, 1276, 32, 309, "Input"],
Cell[9217, 256, 26, 0, 33, "Input"],
Cell[9246, 258, 786, 22, 77, "Text"],
Cell[10035, 282, 439, 18, 45, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[10511, 305, 27, 0, 45, "Section"],
Cell[10541, 307, 329, 7, 51, "Text"],
Cell[CellGroupData[{
Cell[10895, 318, 181, 5, 33, "Input"],
Cell[11079, 325, 1687, 50, 45, "Print"],
Cell[12769, 377, 1124, 35, 370, "Print"],
Cell[13896, 414, 1687, 50, 45, "Print"],
Cell[15586, 466, 1132, 35, 370, "Print"],
Cell[16721, 503, 1687, 50, 45, "Print"],
Cell[18411, 555, 1132, 35, 370, "Print"],
Cell[19546, 592, 1687, 50, 45, "Print"],
Cell[21236, 644, 1132, 35, 370, "Print"],
Cell[22371, 681, 300, 6, 25, "Print"]
}, Open  ]],
Cell[22686, 690, 160, 3, 32, "Text"],
Cell[CellGroupData[{
Cell[22871, 697, 215, 6, 33, "Input"],
Cell[23089, 705, 300, 6, 25, "Print"],
Cell[23392, 713, 94, 2, 33, "Output"]
}, Open  ]],
Cell[23501, 718, 90, 2, 32, "Text"],
Cell[23594, 722, 1369, 44, 53, "Input"],
Cell[CellGroupData[{
Cell[24988, 770, 64, 1, 33, "Input"],
Cell[25055, 773, 1124, 35, 370, "Print"]
}, Open  ]],
Cell[26194, 811, 22, 0, 32, "Text"],
Cell[26219, 813, 1684, 54, 53, "Input"],
Cell[CellGroupData[{
Cell[27928, 871, 64, 1, 33, "Input"],
Cell[27995, 874, 1147, 37, 460, "Print"]
}, Open  ]],
Cell[29157, 914, 25, 0, 32, "Text"],
Cell[29185, 916, 2002, 64, 72, "Input"],
Cell[CellGroupData[{
Cell[31212, 984, 64, 1, 33, "Input"],
Cell[31279, 987, 1380, 42, 246, "Print"]
}, Open  ]],
Cell[32674, 1032, 160, 3, 32, "Text"],
Cell[CellGroupData[{
Cell[32859, 1039, 736, 24, 33, "Input"],
Cell[33598, 1065, 2042, 60, 45, "Print"],
Cell[35643, 1127, 1147, 37, 460, "Print"],
Cell[36793, 1166, 2042, 60, 45, "Print"],
Cell[38838, 1228, 1137, 35, 460, "Print"],
Cell[39978, 1265, 2042, 60, 45, "Print"],
Cell[42023, 1327, 1147, 37, 460, "Print"],
Cell[43173, 1366, 2042, 60, 45, "Print"],
Cell[45218, 1428, 1147, 37, 460, "Print"],
Cell[46368, 1467, 2042, 60, 45, "Print"],
Cell[48413, 1529, 1147, 37, 460, "Print"],
Cell[49563, 1568, 2042, 60, 45, "Print"],
Cell[51608, 1630, 1147, 37, 460, "Print"],
Cell[52758, 1669, 296, 6, 25, "Print"],
Cell[53057, 1677, 96, 2, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[53190, 1684, 1770, 55, 72, "Input"],
Cell[54963, 1741, 1147, 37, 460, "Print"]
}, Open  ]],
Cell[56125, 1781, 109, 5, 32, "Text"],
Cell[CellGroupData[{
Cell[56259, 1790, 4647, 141, 186, "Input"],
Cell[60909, 1933, 312, 9, 51, "Text"],
Cell[CellGroupData[{
Cell[61246, 1946, 64, 1, 33, "Input"],
Cell[61313, 1949, 1424, 42, 460, "Print"]
}, Open  ]]
}, Open  ]],
Cell[62764, 1995, 76, 0, 32, "Text"],
Cell[CellGroupData[{
Cell[62865, 1999, 92, 2, 33, "Input"],
Cell[62960, 2003, 1424, 42, 460, "Print"]
}, Open  ]],
Cell[64399, 2048, 144, 5, 51, "Text"],
Cell[CellGroupData[{
Cell[64568, 2057, 377, 12, 33, "Input"],
Cell[64948, 2071, 2407, 71, 64, "Print"],
Cell[67358, 2144, 1185, 36, 146, "Print"],
Cell[68546, 2182, 2407, 71, 64, "Print"],
Cell[70956, 2255, 1193, 36, 146, "Print"],
Cell[72152, 2293, 2407, 71, 64, "Print"],
Cell[74562, 2366, 1185, 36, 146, "Print"],
Cell[75750, 2404, 2407, 71, 64, "Print"],
Cell[78160, 2477, 1185, 36, 146, "Print"],
Cell[79348, 2515, 2407, 71, 64, "Print"],
Cell[81758, 2588, 1185, 36, 146, "Print"],
Cell[82946, 2626, 2407, 71, 64, "Print"],
Cell[85356, 2699, 1193, 36, 146, "Print"],
Cell[86552, 2737, 2407, 71, 64, "Print"],
Cell[88962, 2810, 1185, 36, 146, "Print"],
Cell[90150, 2848, 2407, 71, 64, "Print"],
Cell[92560, 2921, 1177, 36, 146, "Print"],
Cell[93740, 2959, 2407, 71, 64, "Print"],
Cell[96150, 3032, 1177, 36, 146, "Print"],
Cell[97330, 3070, 2409, 71, 64, "Print"],
Cell[99742, 3143, 1177, 36, 146, "Print"],
Cell[100922, 3181, 2409, 71, 64, "Print"],
Cell[103334, 3254, 1185, 36, 146, "Print"],
Cell[104522, 3292, 2409, 71, 64, "Print"],
Cell[106934, 3365, 1177, 36, 146, "Print"],
Cell[108114, 3403, 2409, 71, 64, "Print"],
Cell[110526, 3476, 1185, 36, 146, "Print"],
Cell[111714, 3514, 2409, 71, 64, "Print"],
Cell[114126, 3587, 1185, 36, 146, "Print"],
Cell[115314, 3625, 2409, 71, 64, "Print"],
Cell[117726, 3698, 1185, 36, 146, "Print"],
Cell[118914, 3736, 2409, 71, 64, "Print"],
Cell[121326, 3809, 1185, 36, 146, "Print"],
Cell[122514, 3847, 304, 6, 25, "Print"],
Cell[122821, 3855, 94, 2, 33, "Output"]
}, Open  ]],
Cell[122930, 3860, 62, 0, 32, "Text"],
Cell[122995, 3862, 3996, 128, 129, "Input"],
Cell[CellGroupData[{
Cell[127016, 3994, 181, 4, 53, "Input"],
Cell[127200, 4000, 1185, 36, 146, "Print"],
Cell[128388, 4038, 1185, 36, 146, "Print"]
}, Open  ]],
Cell[129588, 4077, 16, 0, 32, "Text"],
Cell[129607, 4079, 167, 3, 32, "Text"],
Cell[CellGroupData[{
Cell[129799, 4086, 200, 6, 33, "Input"],
Cell[130002, 4094, 302, 6, 25, "Print"],
Cell[130307, 4102, 94, 2, 33, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
